# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Manipulate netblock lists in CIDR notation
Name:		perl-Net-CIDR
Version:	0.21
Release:	7.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Net-CIDR
Source0:	https://cpan.metacpan.org/modules/by-module/Net/Net-CIDR-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
# Test Suite
# (no additional dependencies)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
The Net::CIDR package contains functions that manipulate lists of IP netblocks
expressed in CIDR notation. The Net::CIDR functions handle both IPv4 and IPv6
addresses.

%prep
%setup -q -n Net-CIDR-%{version} 
 
%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license COPYING
%doc ChangeLog README
%{perl_vendorlib}/Net/
%{_mandir}/man3/Net::CIDR.3*

%changelog
* Wed May  3 2023 Paul Howarth <paul@city-fan.org> - 0.21-7
- Use SPDX-format license tag

* Wed Mar 31 2021 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21
  - Update perldoc to emphasize proper usage of ciddrvalidate()
- Use %%license unconditionally

* Wed Apr 17 2019 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - _ipcmp: Handle comparison of mixed IPv4 and IPv6-specified addresses,
    allowing cidrlookup() to look up IPv6-mapped IPv4 addresses in IPv4
    address ranges, and vice versa

* Tue Jun 12 2018 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19
  - Fix cidrvalidate() checking of IPv6 addresses with a 0 word
  - Update documentation to use only reserved IP addresses
  - Move test.pl to t/
- Switch upstream from search.cpan.org to metacpan.org

* Wed Apr 25 2018 Paul Howarth <paul@city-fan.org> - 0.18-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Sep  9 2016 Paul Howarth <paul@city-fan.org> - 0.18-5
- BR: perl-generators where available
- Simplify find command using -delete

* Wed Feb  4 2015 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18
  - Leading 0s in IPv6 addresses are ok

* Mon Nov 17 2014 Paul Howarth <paul@city-fan.org> - 0.17-2
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible
- Classify buildreqs by usage

* Sun Oct 21 2012 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Version bump, put META back into the tarball

* Mon Oct  1 2012 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16
  - cidrvalidate() corrects octet-shortchanged IPv4 addresses to their proper
    size

* Fri Jun  8 2012 Paul Howarth <paul@city-fan.org> - 0.15-2
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Feb 17 2012 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Corrected cidrvalidate() to return values according to its documentation,
    in some corner cases
- BR: perl(Carp) and perl(Exporter)

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 0.14-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix source URL
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Jun 28 2010 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Corrected some documentation errors
  - cidrvalidate() will validate either an IP address or a CIDR
  - Re-implemented addr2cidr without Math::BigInt, faster for ipv6 addresses

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.13-5
- Rebuild for perl 5.12.1 in Rawhide

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 0.13-4
- Fix dist tag to work with RHEL6 Beta

* Mon Mar  1 2010 Paul Howarth <paul@city-fan.org> - 0.13-3
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Tue Sep 22 2009 Paul Howarth <paul@city-fan.org> - 0.13-2
- Define RPM macros in global scope

* Thu Jan 22 2009 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
- Clarify license at GPL (version 1 or later), or Artistic (i.e. same as perl)
- Tweak dist tag macros to work on Rawhide with three-part releasenum

* Tue Jun  5 2007 Paul Howarth <paul@city-fan.org> - 0.11-3
- Fix dist tag for Fedora 7 onwards
- Fix argument order for find with -depth
- BuildRequire perl(ExtUtils::MakeMaker)

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 0.11-2
- Fix distribution tags for development releases
- define %%{__id_u} in a more portable way
- don't use macros in build-time command paths, hardcode them instead
- remove buildroot unconditionally in %%clean and %%install
- use search.cpan.org URLs

* Fri Aug 12 2005 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11
- Remove optimizations, redundant for noarch package

* Sat Jun  4 2005 Paul Howarth <paul@city-fan.org> - 0.10-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency

* Fri Oct 22 2004 Paul Howarth <paul@city-fan.org> - 0.10-1
- Correct URL
- General tidy-up of spec file
- Update to 0.10

* Thu Apr 15 2004 Paul Howarth <paul@city-fan.org> - 0.09-2
- Added explicit perl dependency to ensure that an RPM built on a
  system with an updated version of perl (and hence having files
  installed in a place that a non-updated system won't find them)
  will not install on the non-updated system. In such cases, just
  rebuild from the source RPM.
- Changed distribution-identifying macros for greater portability.

* Tue Feb 17 2004 Paul Howarth <paul@city-fan.org> - 0.09-1
- Initial RPM build
